Crate aranya_client

Crate aranya_client 

The Aranya client library.

The Aranya Client library provides the following features to application developers:

  • IDAM/RBAC/ABAC (identity & access management, role-based access controls, attribute-based access controls, security controls)
  • Aranya Fast Channels (secure, encrypted data transmission)

For more information refer to:

Modules

afcafc
AFC support.
client
Client-daemon connection.
config
Client configurations.
error
Client API errors.

Macros

text
Creates a Text from a string literal.

Structs

AddTeamConfig
Configuration for joining an existing team.
AddTeamConfigBuilder
Builder for AddTeamConfig.
AddTeamQuicSyncConfig
Configuration for adding members to an existing team with QUIC synchronization.
Addr
A “host:port” network address.
Client
A client for invoking actions on and processing effects from the Aranya graph.
CreateTeamConfig
Configuration for creating a new team.
CreateTeamConfigBuilder
Builder for CreateTeamConfig.
CreateTeamQuicSyncConfig
Configuration for creating a new team with QUIC synchronization.
CreateTeamQuicSyncConfigBuilder
Builder for CreateTeamQuicSyncConfig
Device
Represents an Aranya device
DeviceId
Uniquely identifies a device.
Devices
A list of DeviceId.
KeyBundle
A device’s public key bundle.
Label
A label.
LabelId
An AFC label ID.
Labels
List of labels.
Role
A role.
RoleId
Uniquely identifies a role.
Roles
A set of Roles.
SyncPeerConfig
Configuration info for syncing with a peer.
SyncPeerConfigBuilder
Builder for a SyncPeerConfig
Team
Represents an Aranya Team.
TeamId
Uniquely identifies an Aranya team.
Text
A string-like value which is utf8 without nul bytes.

Enums

ChanOp
Valid channel operations for a label assignment.
ConfigError
Possible errors that could happen when creating configuration info.
Error
Possible errors that could happen in the Aranya client.

Type Aliases

Result
The type returned by fallible Aranya operations.