pub struct Channels { /* private fields */ }Available on crate feature
afc only.Expand description
Aranya Fast Channels handler for managing channels which allow encrypting/decrypting application data buffers.
Implementations
Sourceimpl Channels
impl Channels
Sourcepub const OVERHEAD: usize = AfcClient<ReadState<CS>>::OVERHEAD
pub const OVERHEAD: usize = AfcClient<ReadState<CS>>::OVERHEAD
The number of additional octets required to encrypt plaintext data.
Sourcepub async fn create_channel(
&self,
team_id: TeamId,
peer_id: DeviceId,
label_id: LabelId,
) -> Result<(SendChannel, CtrlMsg)>
pub async fn create_channel( &self, team_id: TeamId, peer_id: DeviceId, label_id: LabelId, ) -> Result<(SendChannel, CtrlMsg)>
Create a unidirectional send-only channel SendChannel.
The creator of the channel will have a unidirectional channel SendChannel that can only seal() data.
Once the peer processes the CtrlMsg message with accept_channel(),
it will have a corresponding unidirectional channel ReceiveChannel object that can only open() data.
To send data from the creator of the channel to the peer:
- Invoke
seal()on the data to obtain a ciphertext buffer. - Send the ciphertext to the peer via any network transport.
- On the peer, invoke
open()on the ciphertext to obtain the plaintext.
Returns:
- A unidirectional channel
SendChannelobject that can onlyseal()data. - A
CtrlMsgmessage to send to the peer.
Sourcepub async fn accept_channel(
&self,
team_id: TeamId,
ctrl: CtrlMsg,
) -> Result<ReceiveChannel>
pub async fn accept_channel( &self, team_id: TeamId, ctrl: CtrlMsg, ) -> Result<ReceiveChannel>
Receive a CtrlMsg message from a peer to create a corresponding receive channel.