SendChannel

Struct SendChannel 

pub struct SendChannel { /* private fields */ }
Available on crate feature afc only.
A unidirectional channel that can only send.

Implementations

Source

impl SendChannel

pub fn id(&self) -> ChannelId

The channel’s unique ID.

pub fn label_id(&self) -> LabelId

The channel’s label ID.

pub fn peer_id(&self) -> DeviceId

The device ID of the peer on the other side of the channel.

pub fn seal(&mut self, dst: &mut [u8], plaintext: &[u8]) -> Result<(), Error>

Encrypts and authenticates plaintext for a channel.

The resulting ciphertext is written to dst, which must be at least plaintext.len() + Channels::OVERHEAD bytes long.

Note: it is an error to invoke this method after the channel has been deleted.

Panics

Will panic on poisoned internal mutexes.

pub async fn delete(&self) -> Result<(), Error>

Delete the channel.