pub struct AddTeamQuicSyncConfig { /* private fields */ }Expand description
Configuration for adding members to an existing team with QUIC synchronization.
Implementations
Sourceimpl AddTeamQuicSyncConfig
impl AddTeamQuicSyncConfig
Sourcepub fn builder() -> AddTeamQuicSyncConfigBuilder
pub fn builder() -> AddTeamQuicSyncConfigBuilder
Creates a new builder for team member addition configuration.