Client

Struct Client 

pub struct Client { /* private fields */ }
A client for invoking actions on and processing effects from the Aranya graph.

Client interacts with the Aranya daemon over a platform-specific IPC mechanism.

Implementations

Source

impl Client

pub fn builder<'a>() -> ClientBuilder<'a>

Returns a builder for Client.

pub async fn local_addr(&self) -> Result<Addr>

Returns the address that the Aranya sync server is bound to.

pub async fn get_key_bundle(&self) -> Result<PublicKeyBundle>

👎Deprecated: Use get_public_key_bundle
pub async fn get_public_key_bundle(&self) -> Result<PublicKeyBundle>

Gets the public key bundle for this device.

pub async fn get_device_id(&self) -> Result<DeviceId>

Gets the public device ID for this device.

pub async fn create_team(&self, cfg: CreateTeamConfig) -> Result<Team<'_>>

Create a new graph/team with the current device as the owner.

pub async fn rand(&self, buf: &mut [u8])

Generate random bytes from a CSPRNG. Can be used to generate IKM for a generating a PSK seed.

pub fn team(&self, team_id: TeamId) -> Team<'_>

Get an existing team.

pub async fn add_team(&self, cfg: AddTeamConfig) -> Result<Team<'_>>

Add a team to local device storage.

pub async fn remove_team(&self, team_id: TeamId) -> Result<()>

Remove a team from local device storage.

pub fn afc(&self) -> AfcChannels

Available on crate feature afc only.

Get access to Aranya Fast Channels.