Device

Struct Device 

pub struct Device<'a> { /* private fields */ }
Represents an Aranya device

Implementations

Source

impl Device<'_>

pub fn id(&self) -> DeviceId

Returns the device’s globally unique ID.

pub async fn keybundle(&self) -> Result<PublicKeyBundle>

👎Deprecated: Use public_key_bundle.
pub async fn public_key_bundle(&self) -> Result<PublicKeyBundle>

Returns device’s public key bundle.

pub async fn remove_from_team(&self) -> Result<()>

Removes device from the team.

pub async fn assign_role(&self, role: RoleId) -> Result<()>

Assigns role to device.

pub async fn revoke_role(&self, role: RoleId) -> Result<()>

Revokes role from device.

pub async fn change_role( &self, old_role: RoleId, new_role: RoleId, ) -> Result<()>

Changes the role on a device

pub async fn role(&self) -> Result<Option<Role>>

Returns the role assigned to the device, if any.

pub async fn label_assignments(&self) -> Result<Labels>

Returns a list of labels assiged to the device.

pub async fn assign_label(&self, label: LabelId, op: ChanOp) -> Result<()>

Assigns label to the device.

pub async fn revoke_label(&self, label: LabelId) -> Result<()>

Revokes label from the device.