Team

Struct Team 

pub struct Team<'a> { /* private fields */ }
Represents an Aranya Team.

Implementations

Source

impl Team<'_>

pub fn team_id(&self) -> TeamId

Return the team’s globally unique ID.

pub async fn close_team(&self) -> Result<()>

Closes the team, preventing any further operations on it.

Source

impl Team<'_>

pub async fn encrypt_psk_seed_for_peer( &self, peer_enc_pk: &[u8], ) -> Result<Vec<u8>>

Encrypts the team’s QUIC syncer PSK seed for a peer. peer_enc_pk is the public encryption key of the peer device. See PublicKeyBundle::encryption.

pub async fn add_sync_peer( &self, addr: Addr, config: SyncPeerConfig, ) -> Result<()>

Adds a peer for automatic periodic Aranya state syncing.

pub async fn sync_now( &self, addr: Addr, cfg: Option<SyncPeerConfig>, ) -> Result<()>

Immediately syncs with the peer.

If config is None, default values (including those from the daemon) will be used.

pub async fn remove_sync_peer(&self, addr: Addr) -> Result<()>

Removes a peer from automatic Aranya state syncing.

Source

impl Team<'_>

pub async fn add_device( &self, keys: PublicKeyBundle, initial_role: Option<RoleId>, ) -> Result<()>

Adds a device to the team with an optional initial role.

pub fn device(&self, id: DeviceId) -> Device<'_>

Returns the Device corresponding with id.

pub async fn devices(&self) -> Result<Devices>

Returns the list of devices on the team.

Source

impl Team<'_>

pub async fn setup_default_roles(&self, owning_role: RoleId) -> Result<Roles>

Sets up the default team roles.

owning_role will be the initial owner of the default roles.

It returns the the roles that were created.

pub async fn role_owners(&self, role: RoleId) -> Result<Roles>

Returns the roles that own role.

pub async fn roles(&self) -> Result<Roles>

Returns all of the roles for this team.

Source

impl Team<'_>

pub async fn create_label( &self, label_name: Text, managing_role_id: RoleId, ) -> Result<LabelId>

Create a label.

pub async fn delete_label(&self, label_id: LabelId) -> Result<()>

Delete a label.

pub async fn add_label_managing_role( &self, label_id: LabelId, managing_role_id: RoleId, ) -> Result<()>

Add label managing role

pub async fn label(&self, label_id: LabelId) -> Result<Option<Label>>

Returns a label if it exists.

pub async fn labels(&self) -> Result<Labels>

Returns the list of labels on the team.