pub struct SendChannel { /* private fields */ }Available on crate feature
afc only.Expand description
A unidirectional channel that can only send.
Implementations
Sourceimpl SendChannel
impl SendChannel
Sourcepub fn seal(&mut self, dst: &mut [u8], plaintext: &[u8]) -> Result<(), Error>
pub fn seal(&mut self, dst: &mut [u8], plaintext: &[u8]) -> Result<(), Error>
Encrypts and authenticates plaintext for a channel.
The resulting ciphertext is written to dst, which must
be at least plaintext.len() + Channels::OVERHEAD bytes
long.
Note: it is an error to invoke this method after the channel has been deleted.
Panics
Will panic on poisoned internal mutexes.