pub struct Client { /* private fields */ }Expand description
A client for invoking actions on and processing effects from the Aranya graph.
Client interacts with the Aranya daemon over
a platform-specific IPC mechanism.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn builder<'a>() -> ClientBuilder<'a>
pub fn builder<'a>() -> ClientBuilder<'a>
Returns a builder for Client.
Sourcepub async fn local_addr(&self) -> Result<Addr>
pub async fn local_addr(&self) -> Result<Addr>
Returns the address that the Aranya sync server is bound to.
Sourcepub async fn get_key_bundle(&self) -> Result<PublicKeyBundle>
👎Deprecated: Use get_public_key_bundle
pub async fn get_key_bundle(&self) -> Result<PublicKeyBundle>
get_public_key_bundleSourcepub async fn get_public_key_bundle(&self) -> Result<PublicKeyBundle>
pub async fn get_public_key_bundle(&self) -> Result<PublicKeyBundle>
Gets the public key bundle for this device.
Sourcepub async fn get_device_id(&self) -> Result<DeviceId>
pub async fn get_device_id(&self) -> Result<DeviceId>
Gets the public device ID for this device.
Sourcepub async fn create_team(&self, cfg: CreateTeamConfig) -> Result<Team<'_>>
pub async fn create_team(&self, cfg: CreateTeamConfig) -> Result<Team<'_>>
Create a new graph/team with the current device as the owner.
Sourcepub async fn rand(&self, buf: &mut [u8])
pub async fn rand(&self, buf: &mut [u8])
Generate random bytes from a CSPRNG. Can be used to generate IKM for a generating a PSK seed.
Sourcepub async fn add_team(&self, cfg: AddTeamConfig) -> Result<Team<'_>>
pub async fn add_team(&self, cfg: AddTeamConfig) -> Result<Team<'_>>
Add a team to local device storage.
Sourcepub async fn remove_team(&self, team_id: TeamId) -> Result<()>
pub async fn remove_team(&self, team_id: TeamId) -> Result<()>
Remove a team from local device storage.
Sourcepub fn afc(&self) -> AfcChannels
Available on crate feature afc only.
pub fn afc(&self) -> AfcChannels
afc only.Get access to Aranya Fast Channels.