pub struct Device<'a> { /* private fields */ }Expand description
Represents an Aranya device
Implementations
Sourceimpl Device<'_>
impl Device<'_>
Sourcepub async fn keybundle(&self) -> Result<PublicKeyBundle>
👎Deprecated: Use public_key_bundle.
pub async fn keybundle(&self) -> Result<PublicKeyBundle>
public_key_bundle.Sourcepub async fn public_key_bundle(&self) -> Result<PublicKeyBundle>
pub async fn public_key_bundle(&self) -> Result<PublicKeyBundle>
Returns device’s public key bundle.
Sourcepub async fn remove_from_team(&self) -> Result<()>
pub async fn remove_from_team(&self) -> Result<()>
Removes device from the team.
Sourcepub async fn assign_role(&self, role: RoleId) -> Result<()>
pub async fn assign_role(&self, role: RoleId) -> Result<()>
Assigns role to device.
Sourcepub async fn revoke_role(&self, role: RoleId) -> Result<()>
pub async fn revoke_role(&self, role: RoleId) -> Result<()>
Revokes role from device.
Sourcepub async fn change_role(
&self,
old_role: RoleId,
new_role: RoleId,
) -> Result<()>
pub async fn change_role( &self, old_role: RoleId, new_role: RoleId, ) -> Result<()>
Changes the role on a device
Sourcepub async fn role(&self) -> Result<Option<Role>>
pub async fn role(&self) -> Result<Option<Role>>
Returns the role assigned to the device, if any.
Sourcepub async fn label_assignments(&self) -> Result<Labels>
pub async fn label_assignments(&self) -> Result<Labels>
Returns a list of labels assiged to the device.
Sourcepub async fn assign_label(&self, label: LabelId, op: ChanOp) -> Result<()>
pub async fn assign_label(&self, label: LabelId, op: ChanOp) -> Result<()>
Assigns label to the device.
Sourcepub async fn revoke_label(&self, label: LabelId) -> Result<()>
pub async fn revoke_label(&self, label: LabelId) -> Result<()>
Revokes label from the device.