pub struct Team<'a> { /* private fields */ }Expand description
Represents an Aranya Team.
Implementations
Sourceimpl Team<'_>
impl Team<'_>
Sourcepub async fn encrypt_psk_seed_for_peer(
&self,
peer_enc_pk: &[u8],
) -> Result<Vec<u8>>
pub async fn encrypt_psk_seed_for_peer( &self, peer_enc_pk: &[u8], ) -> Result<Vec<u8>>
Encrypts the team’s QUIC syncer PSK seed for a peer.
peer_enc_pk is the public encryption key of the peer device.
See PublicKeyBundle::encryption.
Sourcepub async fn add_sync_peer(
&self,
addr: Addr,
config: SyncPeerConfig,
) -> Result<()>
pub async fn add_sync_peer( &self, addr: Addr, config: SyncPeerConfig, ) -> Result<()>
Adds a peer for automatic periodic Aranya state syncing.
Sourcepub async fn sync_now(
&self,
addr: Addr,
cfg: Option<SyncPeerConfig>,
) -> Result<()>
pub async fn sync_now( &self, addr: Addr, cfg: Option<SyncPeerConfig>, ) -> Result<()>
Immediately syncs with the peer.
If config is None, default values (including those from the daemon) will
be used.
Sourcepub async fn remove_sync_peer(&self, addr: Addr) -> Result<()>
pub async fn remove_sync_peer(&self, addr: Addr) -> Result<()>
Removes a peer from automatic Aranya state syncing.
Sourceimpl Team<'_>
impl Team<'_>
Sourcepub async fn add_device(
&self,
keys: PublicKeyBundle,
initial_role: Option<RoleId>,
) -> Result<()>
pub async fn add_device( &self, keys: PublicKeyBundle, initial_role: Option<RoleId>, ) -> Result<()>
Adds a device to the team with an optional initial role.
Sourceimpl Team<'_>
impl Team<'_>
Sourcepub async fn setup_default_roles(&self, owning_role: RoleId) -> Result<Roles>
pub async fn setup_default_roles(&self, owning_role: RoleId) -> Result<Roles>
Sets up the default team roles.
owning_role will be the initial owner of the default
roles.
It returns the the roles that were created.
Sourcepub async fn role_owners(&self, role: RoleId) -> Result<Roles>
pub async fn role_owners(&self, role: RoleId) -> Result<Roles>
Returns the roles that own role.
Sourceimpl Team<'_>
impl Team<'_>
Sourcepub async fn create_label(
&self,
label_name: Text,
managing_role_id: RoleId,
) -> Result<LabelId>
pub async fn create_label( &self, label_name: Text, managing_role_id: RoleId, ) -> Result<LabelId>
Create a label.
Sourcepub async fn delete_label(&self, label_id: LabelId) -> Result<()>
pub async fn delete_label(&self, label_id: LabelId) -> Result<()>
Delete a label.
Sourcepub async fn add_label_managing_role(
&self,
label_id: LabelId,
managing_role_id: RoleId,
) -> Result<()>
pub async fn add_label_managing_role( &self, label_id: LabelId, managing_role_id: RoleId, ) -> Result<()>
Add label managing role